# aayush-color

## A simple python program to convert a color format to another color format.

---

# Use the package in your project

### Install the package

```
pip install aayush-color
```

### Using the package

```
import aayush_color.color as color

color.hex_to_rgb("#ffffff")
```

---

Aayush Nagpal © 2023

> **Note**
> This is for a university project. Might not be maintained in future.
